@@ -5,8 +5,8 @@
 #'
 #' Compute the continuum removed values of a data matrix or vector
 #' @usage
-#' continuumRemoval(X, wav, type = c("R", "A"), 
-#'                  interpol = c("linear", "spline"), 
+#' continuumRemoval(X, wav, type = c("R", "A"),
+#'                  interpol = c("linear", "spline"),
 #'                  method = c("division", "substraction"))
 #' @param X a numeric matrix or vector to process (optionally a data frame that can
 #' be coerced to a numerical matrix).
@@ -33,27 +33,26 @@
 #' #  # type = 'A' is used for absorbance spectra
 #' cr <- continuumRemoval(NIRsoil$spc, wav, type = "A")
 #' matlines(wav, t(cr[1:10, ]))
-#' 
-#' @seealso 
-#' \code{\link{savitzkyGolay}}, \code{\link{movav}}, 
+#' @seealso
+#' \code{\link{savitzkyGolay}}, \code{\link{movav}},
 #' \code{\link{gapDer}}, \code{\link{binning}}
-#' @details  
+#' @details
 #' The continuum removal technique was introduced by Clark and Roush (1984)
 #' as a method to highlight energy absorption features of minerals.
 #' It can be viewed as a way to perform albedo normalization.
-#' The algorithm find points lying on the convex hull (local maxima or envelope) 
+#' The algorithm find points lying on the convex hull (local maxima or envelope)
 #' of a spectrum, connects the points by linear or spline interpolation and
-#' normalizes the spectrum by dividing (or subtracting) the input data by the 
+#' normalizes the spectrum by dividing (or subtracting) the input data by the
 #' interpolated line.
-#' @references 
-#' Clark, R.N., and Roush, T.L., 1984. Reflectance Spectroscopy: Quantitative 
-#' Analysis Techniques for Remote Sensing Applications. J. Geophys. Res. 89, 
+#' @references
+#' Clark, R.N., and Roush, T.L., 1984. Reflectance Spectroscopy: Quantitative
+#' Analysis Techniques for Remote Sensing Applications. J. Geophys. Res. 89,
 #' 6329-6340.
 #' @export
 
-continuumRemoval <- function(X, 
-                             wav, 
-                             type = c("R", "A"), 
+continuumRemoval <- function(X,
+                             wav,
+                             type = c("R", "A"),
                              interpol = c("linear", "spline"),
                              method = c("division", "substraction")) {
   if (is.data.frame(X)) {
@@ -71,11 +70,14 @@ continuumRemoval <- function(X,
   crfun <- function(x, wav, interpol) {
     id <- sort(chull(c(wav[1] - 1, wav, wav[length(wav)] + 1), c(0, x, 0)))
     id <- id[-c(1, length(id))] - 1
-    cont <- switch(interpol, linear = {
-      approx(x = wav[id], y = x[id], xout = wav, method = "linear")$y
-    }, spline = {
-      splinefun(x = wav[id], y = x[id])(wav)
-    })
+    cont <- switch(interpol,
+      linear = {
+        approx(x = wav[id], y = x[id], xout = wav, method = "linear")$y
+      },
+      spline = {
+        splinefun(x = wav[id], y = x[id])(wav)
+      }
+    )
     return(cont)
   }
 
