@@ -3,12 +3,12 @@
 #' Select calibration samples from a large multivariate data using the DUPLEX
 #' algorithm
 #' @usage
-#' duplex(X, 
-#'        k, 
-#'        metric = c("mahal", "euclid"), 
-#'        pc, 
-#'        group, 
-#'        .center = TRUE, 
+#' duplex(X,
+#'        k,
+#'        metric = c("mahal", "euclid"),
+#'        pc,
+#'        group,
+#'        .center = TRUE,
 #'        .scale = FALSE)
 #' @param X a numeric matrix.
 #' @param k the number of calibration/validation samples.
@@ -18,22 +18,22 @@
 #' the samples. If not specified, distance are computed in the Euclidean space.
 #' Alternatively, distances are computed in the principal component space and
 #' `pc` is the number of principal components retained.
-#' If `pc < 1`, the number of principal components kept corresponds to the 
+#' If `pc < 1`, the number of principal components kept corresponds to the
 #' number
 #' of components explaining at least (`pc * 100`) percent of the total variance.
 #' @param group An optional `factor` (or vector that can be coerced to a factor
 #' by \code{\link{as.factor}}) of length equal to nrow(X), giving the identifier
 #' of related observations (e.g. samples of the same batch of measurements,
-#' samples of the same origin, or of the same soil profile). When one 
+#' samples of the same origin, or of the same soil profile). When one
 #' observation is
 #' selected by the procedure all observations of the same group are removed
 #' together and assigned to the calibration/validation sets. This allows to
-#' select calibration and validation samples that are independent from each 
+#' select calibration and validation samples that are independent from each
 #' other.
-#' @param .center logical value indicating whether the input matrix should be
+#' @param .center logical value indicating whether the input matrix must be
 #' centered before projecting `X` onto the Principal Component space.
 #' Analysis. Default set to \code{TRUE}.
-#' @param .scale logical value indicating whether the input matrix should be
+#' @param .scale logical value indicating whether the input matrix must be
 #' scaled before `X` onto the Principal Component space.
 #' Analysis. Default set to \code{FALSE}.
 #' @return a `list` with components:
@@ -78,18 +78,17 @@
 #' sel <- duplex(X, k = 25, metric = "mahal")
 #' points(X[sel$model, ], pch = 19, col = 2) # points selected for calibration
 #' points(X[sel$test, ], pch = 15, col = 3) # points selected for validation
-#' 
-#' @seealso 
-#' \code{\link{kenStone}}, \code{\link{honigs}}, \code{\link{shenkWest}}, 
+#' @seealso
+#' \code{\link{kenStone}}, \code{\link{honigs}}, \code{\link{shenkWest}},
 #' \code{\link{naes}}
 #' @export
 
-duplex <- function(X, 
-                   k, 
-                   metric = c("mahal", "euclid"), 
-                   pc, 
-                   group, 
-                   .center = TRUE, 
+duplex <- function(X,
+                   k,
+                   metric = c("mahal", "euclid"),
+                   pc,
+                   group,
+                   .center = TRUE,
                    .scale = FALSE) {
   if (missing(k)) {
     stop("'k' must be specified")
@@ -98,7 +97,7 @@ duplex <- function(X,
     stop("'X' must have at least 2 columns")
   }
   if (k < 2) {
-    stop("Invalid argument: 'k' should be higher than 2")
+    stop("Invalid argument: 'k' must be higher than 2")
   }
   metric <- match.arg(metric)
   if (is.data.frame(X)) {
@@ -135,7 +134,7 @@ duplex <- function(X,
 
   if (!missing(group)) {
     if (length(group) != nrow(X)) {
-      stop("length(group) should be equal to nrow(X)")
+      stop("length(group) must be equal to nrow(X)")
     }
     if (!is.factor(group)) {
       group <- as.factor(group)
