@@ -6,7 +6,7 @@
 #' \pkg{base}.
 #' @usage
 #' resample(X, wav, new.wav, interpol = "spline", ...)
-#' @param X numeric matrix or vector to resample (optionally a data frame that 
+#' @param X numeric matrix or vector to resample (optionally a data frame that
 #' can be coerced to a numerical matrix).
 #' @param wav a numeric vector giving the original band positions.
 #' @param new.wav a numeric vector giving the new band positions.
@@ -21,10 +21,9 @@
 #' NIRsoil$spc_resampled <- resample(NIRsoil$spc, wav, seq(1100, 2498, 2))
 #' dim(NIRsoil$spc)
 #' dim(NIRsoil$spc_resampled)
-#' 
-#' @return 
+#' @return
 #' a matrix or vector with resampled values.
-#' @seealso 
+#' @seealso
 #' \code{\link{resample2}}
 #' @export
 #'
@@ -33,7 +32,7 @@ resample <- function(X, wav, new.wav, interpol = "spline", ...) {
     X <- as.matrix(X)
   }
   if (missing(wav)) {
-    stop("wav argument should be specified")
+    stop("wav argument must be specified")
   }
 
   if (!interpol %in% c("linear", "spline")) {
@@ -50,7 +49,7 @@ resample <- function(X, wav, new.wav, interpol = "spline", ...) {
 
   if (is.matrix(X)) {
     if (length(wav) != ncol(X)) {
-      stop("length(wav) should be equal to ncol(X)")
+      stop("length(wav) must be equal to ncol(X)")
     }
 
     output <- t(apply(X, 1, resfun, interpol))
@@ -58,7 +57,7 @@ resample <- function(X, wav, new.wav, interpol = "spline", ...) {
     colnames(output) <- new.wav
   } else {
     if (length(wav) != length(X)) {
-      stop("length(wav) should be equal to length(X)")
+      stop("length(wav) must be equal to length(X)")
     }
     output <- resfun(X, interpol)
     names(output) <- new.wav
